# :checkered_flag: 我熟悉 ABM

如果您了解 ABM 相关的概念，并有基本的 Python 编程经验，那么使用 `ABSESpy` 应该比较容易。
请不要被 SES 的概念吓到，这只是一个研究人类与环境交互的理论框架。

!!! note "注意"

    事实上，大多数已发表的 ABM 都包含环境系统，它们只是没有使用 SES 的概念。

下表可以帮助您了解使用 `ABSESpy` 在哪些方面可以提高开发效率，以及它适用于哪种类型的基于智能体的建模。

| 检查项      | 相关资源                          |
| ----------- | ------------------------------------ |
| :material-grid: 智能体移动的空间；通常是网格空间       | :bulb: 空间数据 |
| :material-clock-time-two: 模型时间对应具体的现实世界时间 | :bulb: [时间控制] |
| :material-human-greeting: 智能体有决策要做，像人类一样 | :bulb: [人类行为框架] |
| :material-database-cog: 数据输入/输出，特别是现实世界的地理数据 | :bulb: 数据管理 |

除了上述特定功能外，使用 `ABSESpy` 实现 ABM 的整体情况可以从[快速开始教程]中找到。

<!-- links -->
  [快速开始教程]: ../home/get_started.md
  [时间控制]: ../tutorial/beginner/time_control.ipynb

